#!/bin/sh
# Copyright start
# Copyright (C) 2008 - 2020 Fortinet Inc.
# All rights reserved.
# FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
# Copyright end


logcollect(){
    LOGPATH=$1
    set -e
    if [ "X$LOGPATH" = "X" ]; then
        echo "Enter path where logs should be collected(if not specified, logs are collected in the current working directory): "
        read LOGPATH
    fi
    
    if [ -z $LOGPATH ]; then
        #User has not entered any value, hence consider PWD
        LOGPATH=$(pwd)
    fi

    if [ ! -d $LOGPATH ]; then
        echo "The directory [$LOGPATH] does not exist. Enter a valid directory path."
        exit 1
    fi

    #User can enter relative path like '.' i.e current directory or ../../. Convert it to absolute path
    LOGPATH=$(cd $LOGPATH; pwd)

    declare -r LOGDIR="$LOGPATH/fortisoar-logs"
    declare -r LOGFILE="$LOGDIR.tar.gz"

    if [ -f $LOGFILE.gpg ]; then
        rm $LOGFILE.gpg
    fi

    if [ -d $LOGDIR ]; then
        rm -r $LOGDIR
    fi
    mkdir $LOGDIR

    declare -a logpaths=(
        "/var/log/cyops"
        "/var/log/mongodb"
        "/var/log/nginx"
        "/var/log/elasticsearch"
        "/var/log/messages"
        "/var/log/audit"
        "/var/log/rabbitmq"
        "/var/log/redis"
        "/var/log/php-fpm/"
    )

    echo "Collecting logs"
    for item in "${logpaths[@]}"
    do
        if [ -f $item ] || [ -d $item ]; then
            cp -r --parents $item $LOGDIR
        fi
    done
    echo "Compressing logs"
    tar czf $LOGFILE -C $LOGPATH fortisoar-logs/
    gpg --yes --batch --passphrase=0zy7xpyJaJaOUY9x -o $LOGFILE.gpg --cipher-algo AES256 --symmetric $LOGFILE
    rm -rf $LOGFILE $LOGDIR
    echo "Logs collected at: "$LOGFILE.gpg
}

subcmd_help(){
    help_type=$1
    s_help_one_liner="Collect logs"
    if [ "detailed" = "$help_type" ];then
        echo "$s_help_one_liner"
        echo "usage: csadm log [options]"
        echo ""
        echo "subcommand options are:"
        echo "    --collect [<LOG_PATH>]  Perform log collection."
        echo "                            Collected logs are bundled into fortisoar-logs.tar.gz.gpg"
        echo "    --help            Show this text"
    elif [ "short" = "$help_type" ];then
        echo "$s_help_one_liner"
    fi
}

subcmd_implementation(){
    case "$1" in
        --collect)
            logcollect $2
            break ;;

        -h|--help)
            subcmd_help "detailed"
            break ;;

        *)
            subcmd_help "detailed"
            break ;;
    esac
}

main(){
    subcmd_implementation "$@"
}

main "$@"
exit 0
